@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
-__version__ = '0.0.7'
+__version__ = '0.0.12'
 
 import os
 from pathlib import Path
 
 # Get the location of this module, useful for builtin file operations.
 MODULE_PATH = Path(os.path.realpath(__file__)).parent
+
+# Define exit codes.
+EXITCODE = -1
